#
# spec file for package borgmatic
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           borgmatic
Version:        1.5.1
Release:        3.1
Summary:        Automation tool for borgbackup
License:        GPL-3.0-only
Group:          Productivity/Archiving/Backup
URL:            https://torsion.org/borgmatic/
Source:         https://github.com/witten/borgmatic/archive/%{version}.tar.gz#/borgmatic-%{version}.tar.gz
# testing requirements
BuildRequires:  borgbackup
# To create the manpage
BuildRequires:  pandoc
BuildRequires:  python3 >= 3.4
BuildRequires:  python3-PyYAML
BuildRequires:  python3-appdirs
BuildRequires:  python3-atomicwrites
BuildRequires:  python3-attrs
BuildRequires:  python3-black
BuildRequires:  python3-click
BuildRequires:  python3-colorama
BuildRequires:  python3-coverage
BuildRequires:  python3-devel
BuildRequires:  python3-docopt
BuildRequires:  python3-flake8
BuildRequires:  python3-flexmock
BuildRequires:  python3-mccabe
BuildRequires:  python3-more-itertools
BuildRequires:  python3-pluggy
BuildRequires:  python3-py
BuildRequires:  python3-pycodestyle
BuildRequires:  python3-pyflakes
BuildRequires:  python3-pykwalify
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-cov
BuildRequires:  python3-python-dateutil
BuildRequires:  python3-requests
BuildRequires:  python3-ruamel.yaml
BuildRequires:  python3-setuptools
BuildRequires:  python3-six
BuildRequires:  python3-toml
BuildRequires:  pkgconfig(libsystemd)
Requires:       borgbackup
Requires:       python3-colorama
Requires:       python3-pykwalify
Requires:       python3-requests
Requires:       python3-ruamel.yaml
Requires:       python3-setuptools
BuildArch:      noarch

%description
borgmatic is a Python wrapper script for the Borg backup software
that initiates a backup, prunes any old backups according to a
retention policy, and validates backups for consistency. The script
supports specifying your settings in a declarative configuration file
rather than having to put them all on the command-line, and handles
common errors.

%prep
%setup -q

# Make sample files use the borgmatic command on /usr/bin, not /usr/local/bin
perl -pi -e "s,PATH=\\$PATH:/usr/local/bin /root/.local/bin/borgmatic,/usr/bin/borgmatic," sample/cron/borgmatic
perl -pi -e "s,/root/.local/bin/borgmatic,/usr/bin/borgmatic," sample/systemd/borgmatic.service
perl -pi -e "s,=sleep,=/usr/bin/sleep," sample/systemd/borgmatic.service
perl -pi -e "s,=systemd-inhibit,=/usr/bin/systemd-inhibit," sample/systemd/borgmatic.service
perl -pi -e "s/ruamel.yaml>0.15.0,<0.17.0/ruamel.yaml/" setup.py
perl -pi -e "s/packages=find_packages\(\)/packages=find_packages(exclude=('tests*',))/" setup.py

%build
# Create the manpage
pandoc -s -f markdown -t man README.md -o borgmatic.1

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -d %{buildroot}%{_sysconfdir}/borgmatic
install -d %{buildroot}%{_sysconfdir}/borgmatic.d
install -d %{buildroot}%{_docdir}/%{name}/sample/cron
install -m 0644 sample/cron/borgmatic %{buildroot}%{_docdir}/%{name}/sample/cron/
install -d %{buildroot}%{_unitdir}/
install -m 0644 sample/systemd/borgmatic* %{buildroot}%{_unitdir}/

install -D -m 0644 borgmatic.1 %{buildroot}%{_mandir}/man1/borgmatic.1
mkdir -p %{buildroot}/usr/sbin
ln -s /usr/sbin/service %{buildroot}/usr/sbin/rcborgmatic

%check
# testing the build is a little awkward, since the original testsuite is based on tox and
# tox tries to create a virtual environment, that we need tight control on in order to get
# it to behave in our build system (offline mode, use site packages). OTOH, without the
# venv, we face problems with setuptools (borg uses pkg_resources to locate the installed
# package), while py.test relies on the usual module handling. <hpj@urpla.net>
export LANG=en_US.UTF-8
python3 -m venv --system-site-packages --without-pip borgmatic-env
source borgmatic-env/bin/activate
python3 setup.py install
PYTHONPATH=$(pwd) py.test -v --pyargs borgmatic tests

%post
%service_add_post borgmatic.service
if [ "$1" == 1 -a ! -f "/etc/borgmatic/config.yaml" ]; then
    /usr/bin/generate-borgmatic-config
elif [ "$1" == 2 ]; then
    if [ -f "/etc/borgmatic/config" -a ! -f "/etc/borgmatic/config.yaml" ]; then
       echo "The configuration files have changed. /usr/bin/upgrade-borgmatic-config will be run now to upgrade the configuration to the new format."
       echo ""
       /usr/bin/upgrade-borgmatic-config
    fi
fi

%pre
%service_add_pre borgmatic.service

%preun
%service_del_preun borgmatic.service

%postun
%service_del_postun borgmatic.service

%files
%doc AUTHORS NEWS README.md
%license LICENSE
%config %ghost %{_sysconfdir}/borgmatic/config.yaml
%dir %{_sysconfdir}/borgmatic
%dir %{_sysconfdir}/borgmatic.d
%dir %{_docdir}/%{name}/sample
%dir %{_docdir}/%{name}/sample/cron
%{python3_sitelib}/borgmatic/
%{python3_sitelib}/borgmatic-%{version}-py%{py3_ver}.egg-info
%{_unitdir}/borgmatic.service
%{_unitdir}/borgmatic.timer
%{_bindir}/borgmatic
%{_sbindir}/rcborgmatic
%{_bindir}/generate-borgmatic-config
%{_bindir}/upgrade-borgmatic-config
%{_bindir}/validate-borgmatic-config
%{_mandir}/man1/borgmatic.1%{?ext_man}
%{_docdir}/%{name}/sample/cron

%changelog
* Sat Mar 14 2020 Antonio Larrosa <alarrosa@suse.com>
- Use `python3 -m venv` instead of invoking pyvenv which doesn't seem
  to exist anymore with python 3.8.
* Sun Feb 23 2020 simmphonie@opensuse.org
- Fix execution path in borgmatic.service
* Tue Feb  4 2020 Martin Rey <mrey@suse.com>
- Update to 1.5.1
  * #289: Tired of looking up the latest successful archive name in
  order to pass it to borgmatic actions? Me too. Now you can
  specify "--archive latest" to all actions that accept an archive
  flag.
  * 290: Fix the "--stats" and "--files" flags so that they yield
  output at verbosity 0.
  * Reduce the default verbosity of borgmatic logs sent to
  Healthchecks monitoring hook. Now, it's warnings and errors
  only. You can increase the verbosity via the
  "--monitoring-verbosity" flag.
  * Add security policy documentation in SECURITY.md.
* Tue Jan 28 2020 Martin Rey <mrey@suse.com>
- Update to 1.5.0
  * #245: Monitor backups with PagerDuty hook integration. See the
  documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/monitor-your-backups/#pagerduty-hook
  * #255: Add per-action hooks: "before_prune", "after_prune",
  "before_check", and "after_check".
  * #274: Add ~/.config/borgmatic.d as another configuration
  directory default.
  * #277: Customize Healthchecks log level via borgmatic
  "--monitoring-verbosity" flag.
  * #280: Change "exclude_if_present" option to support multiple
  filenames that indicate a directory should be excluded from
  backups, rather than just a single filename.
  * #284: Backup to a removable drive or intermittent server via
  "soft failure" feature. See the documentation for more
  information:
  https://torsion.org/borgmatic/docs/how-to/backup-to-a-removable-drive-or-an-intermittent-server/
  * #287: View consistency check progress via "--progress" flag for
  "check" action. For "create" and "prune" actions, no longer list
  files or show detailed stats at any verbosities by default. You
  can opt back in with "--files" or "--stats" flags. For "list"
  and "info" actions, show repository names even at verbosity 0.
* Wed Jan 22 2020 Martin Rey <mrey@suse.com>
- Update to 1.4.2
  * Extract files to a particular directory via "borgmatic extract --destination" flag.
  * Rename "borgmatic extract --restore-path" flag to "--path" to reduce confusion with the separate
  "borgmatic restore" action. Any uses of "--restore-path" will continue working.
- Update to 1.4.1
  * #229: Restore backed up PostgreSQL databases via "borgmatic restore" action. See the
  documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/backup-your-databases/
  * Documentation on how to develop borgmatic's documentation:
  https://torsion.org/borgmatic/docs/how-to/develop-on-borgmatic/#documentation-development
- Update to 1.4.0
  * #225: Database dump hooks for PostgreSQL, so you can easily dump your databases before backups
  run.
  * #230: Rename "borgmatic list --pattern-from" flag to "--patterns-from" to match Borg.
- Update to 1.3.26
  * #224: Fix "borgmatic list --successful" with a slightly better heuristic for listing successful
  (non-checkpoint) archives.
- Update to 1.3.25
  * #223: Dead man's switch to detect when backups start failing silently, implemented via
  healthchecks.io hook integration. See the documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/monitor-your-backups/#healthchecks-hook
  * Documentation on monitoring and alerting options for borgmatic backups:
  https://torsion.org/borgmatic/docs/how-to/monitor-your-backups/
  * Automatically rewrite links when developing on documentation locally.
- Update to 1.3.24
  * #86: Add "borgmatic list --successful" flag to only list successful (non-checkpoint) archives.
  * Add a suggestion form to all documentation pages, so users can submit ideas for improving the
  documentation.
  * Update documentation link to community Arch Linux borgmatic package.
- Update to 1.3.23
  * #174: More detailed error alerting via runtime context available in "on_error" hook.
- Update to 1.3.22
  * #144: When backups to one of several repositories fails, keep backing up to the other
  repositories and report errors afterwards.
- Update to 1.3.21
  * #192: User-defined hooks for global setup or cleanup that run before/after all actions. See the
  documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/add-preparation-and-cleanup-steps-to-backups/
- Update to 1.3.20
  * #205: More robust sample systemd service: boot delay, network dependency, lowered CPU/IO
  priority, etc.
  * #221: Fix "borgmatic create --progress" output so that it updates on the console in real-time.
- Update to 1.3.19
  * #219: Fix visibility of "borgmatic prune --stats" output.
- Update to 1.3.18
  * #220: Fix regression of argument parsing for default actions.
- Update to 1.3.17
  * #217: Fix error with "borgmatic check --only" command-line flag with "extract" consistency check.
- Update to 1.3.16
  * #210: Support for Borg check --verify-data flag via borgmatic "data" consistency check.
  * #210: Override configured consistency checks via "borgmatic check --only" command-line flag.
  * When generating sample configuration with generate-borgmatic-config, add a space after each "#"
  comment indicator.
- Update to 1.3.15
  * #208: Fix for traceback when the "checks" option has an empty value.
  * #209: Bypass Borg error about a moved repository via "relocated_repo_access_is_ok" option in
  borgmatic storage configuration section.
  * #213: Reorder arguments passed to Borg to fix duplicate directories when using Borg patterns.
  * #214: Fix for hook erroring with exit code 1 not being interpreted as an error.
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  Allow OBS to shortcut through the -mini flavors.
* Tue Sep  3 2019 Antonio Larrosa <alarrosa@suse.com>
- Fix regexes in spec file now that upstream changed the default borgmatic
  location in the cron and systemd sample files, so we replace them correctly
  with the /usr/bin locations we need for borgmatic to be found.
- Add missing python3-colorama runtime dependency
* Wed Aug 21 2019 simmphonie@opensuse.org
- Update to 1.3.14
  * #204: Do not treat Borg warnings (exit code 1) as failures.
  * When validating configuration files, require strings instead of allowing any scalar type.
- Update to 1.3.13
  * #199: Add note to documentation about using spaces instead of tabs for indentation, as YAML does
  not allow tabs.
  * #203: Fix compatibility with ruamel.yaml 0.16.x.
  * If a "prefix" option in borgmatic's configuration has an empty value (blank or ""), then disable
  default prefix.
- Update to 1.3.12
  * Only log to syslog when run from a non-interactive console (e.g. a cron job).
  * Remove unicode byte order mark from syslog output so it doesn't show up as a literal in rsyslog
  output. See discussion on #197.
- Update to 1.3.11
  * #193: Pass through several "borg list" and "borg info" flags like --short, --format, --sort-by,
  - -first, --last, etc. via borgmatic command-line flags.
  * Add borgmatic info --repository and --archive command-line flags to display info for individual
  repositories or archives.
  * Support for Borg --noatime, --noctime, and --nobirthtime flags via corresponding options in
  borgmatic configuration location section.
- Update to 1.3.10
  * #198: Fix for Borg create error output not showing up at borgmatic verbosity level zero.
- Update to 1.3.9
  * #195: Switch to command-line actions as more traditional sub-commands, e.g. "borgmatic create",
  "borgmatic prune", etc. However, the classic dashed options like "--create" still work!
- Update to 1.3.8
  * #191: Disable console color via "color" option in borgmatic configuration output section.
- Update to 1.3.7
  * #196: Fix for unclear error message for invalid YAML merge include.
  * #197: Don't color syslog output.
  * Change default syslog verbosity to show errors only.
- Update to 1.3.6
  * #53: Log to syslog in addition to existing console logging. Add --syslog-verbosity flag to
  customize the log level. See the documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/inspect-your-backups/
  * #178: Look for .yml configuration file extension in addition to .yaml.
  * #189: Set umask used when executing hooks via "umask" option in borgmatic hooks section.
  * Remove Python cache files before each Tox run.
  * Add #borgmatic Freenode IRC channel to documentation.
  * Add Borg/borgmatic hosting providers section to documentation.
  * Add files for building documentation into a Docker image for web serving.
  * Upgrade project build server from Drone 0.8 to 1.1.
  * Build borgmatic documentation during continuous integration.
  * We're nearly at 500 ★s on GitHub. We can do this!
- Update to 1.3.5
  * #153: Support for various Borg directory environment variables (BORG_CONFIG_DIR, BORG_CACHE_DIR,
  etc.) via options in borgmatic's storage configuration.
  * #177: Fix for regression with missing verbose log entries.
- Update to 1.3.4
  * Part of #125: Color borgmatic (but not Borg) output when using an interactive terminal.
  * #166: Run tests for all installed versions of Python.
  * #168: Update README with continuous integration badge.
  * #169: Automatically sort Python imports in code.
  * Document installing borgmatic with pip install --user instead of a system Python install.
  * Get more reproducible builds by pinning the versions of pip and tox used to run tests.
  * Factor out build/test configuration from tox.ini file.
- Update to 1.3.3
  * Add validate-borgmatic-config command, useful for validating borgmatic config generated by
  configuration management or even edited by hand.
- Update to 1.3.2
  * #160: Fix for hooks executing when using --dry-run. Now hooks are skipped during a dry run.
* Sun May  5 2019 Torsten Gruner <t.gruner@katodev.de>
- Update to 1.3.1
  * #155: Fix for invalid JSON output when using multiple borgmatic configuration files.
  * #157: Fix for seemingly random filename ordering when running through a directory of
    configuration files.
  * Fix for empty JSON output when using --create --json.
  * Now capturing Borg output only when --json flag is used. Previously, borgmatic delayed Borg
    output even without the --json flag.
- Update to 1.3.0
  * #148: Configuration file includes and merging via "!include" tag to support reuse of common
    options across configuration files.
- Update to 1.2.18
  * #147: Support for Borg create/extract --numeric-owner flag via "numeric_owner" option in
    borgmatic's location section.
- Update to 1.2.17
  * #140: List the files within an archive via --list --archive option.
- Update to 1.2.16
  * #119: Include a sample borgmatic configuration file in the documentation.
  * #123: Support for Borg archive restoration via borgmatic --extract command-line flag.
  * Refactor documentation into multiple separate pages for clarity and findability.
  * Organize options within command-line help into logical groups.
  * Exclude tests from distribution packages.
- Update to 1.2.15
  * #127: Remove date echo from schema example, as it's not a substitute for real logging.
  * #132: Leave exclude_patterns glob expansion to Borg, since doing it in borgmatic leads to
    confusing behavior.
  * #136: Handle and format validation errors raised during argument parsing.
  * #138: Allow use of --stats flag when --create or --prune flags are implied.
* Mon Jan 21 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.2.14
  * When generating sample configuration with generate-borgmatic-config,
    document the defaults for each option.
  * When running multiple configuration files, attempt all configuration
    files even if one of them errors. Log a summary of results at the end.
  * Add borgmatic --version command-line flag to get the current installed
    version number.
- Update to 1.2.13
  * Support for --stats command-line flag independent of --verbosity.
  * With borgmatic --init command-line flag, proceed without erroring if a
    repository already exists.
- Update to 1.2.12
  * Support for Borg repository initialization via borgmatic --init
    command-line flag.
  * Update Borg create --filter values so a dry run lists files to back up.
  * Update README with link to a new/forked Docker image.
  * Prevent deprecated --excludes command-line option from being used.
  * Refactor README a bit to flow better for first-time users.
  * Update README with a few additional borgmatic packages (Debian and Ubuntu).
- Update to 1.2.11
  * Support for Borg create --progress via borgmatic command-line flag.
- Update to 1.2.10
  * Support for Borg --chunker-params create option via "chunker_params"
    in borgmatic's storage section.
- Update to 1.2.9
  * Fix for syntax error that occurred in Python 3.5 and below.
  * Make automated tests support running in Python 3.5.
- Update to 1.2.8
  * Enable consistency checks for only certain repositories via
    "check_repositories" option in borgmatic's consistency
    configuration. Handy for large repositories that take forever to check.
  * Include link to issue tracker within various command output.
  * Run continuous integration tests on a matrix of Python and Borg
    versions.
- Update to 1.2.7
  * Support for Borg --keep-secondly prune option.
  * Use Black code formatter and Flake8 code checker as part of running
    automated tests.
  * Add an end-to-end automated test that actually integrates with Borg.
  * Set up continuous integration for borgmatic automated tests
- Update to 1.2.6
  * Fix generated configuration to also include a "keep_daily" value so
    pruning works out of the box.
- Update to 1.2.5
  * Fix various warnings.
- Update to 1.2.4
  * Bump version.
- Update to 1.2.3
  * Set to release version.
* Fri Sep 14 2018 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.2.2
  * #85: Fix compatibility issue between pykwalify and ruamel.yaml 0.15.52, which manifested in
  borgmatic as a pykwalify RuleError.
- Update to 1.2.1
  * Skip before/after backup hooks when only doing --prune, --check, --list, and/or --info.
  * #71: Support for XDG_CONFIG_HOME environment variable for specifying alternate user ~/.config/
  path.
  * #74, #83: Support for Borg --json option via borgmatic command-line to --list archives or show
  archive --info in JSON format, ideal for programmatic consumption.
  * #38, #76: Upgrade ruamel.yaml compatibility version range and fix support for Python 3.7.
  * #77: Skip non-"*.yaml" config filenames in /etc/borgmatic.d/ so as not to parse backup files,
  editor swap files, etc.
  * #81: Document user-defined hooks run before/after backup, or on error.
  * Add code style guidelines to the documention.
* Sat Jul  7 2018 alarrosa@suse.com
- Use %%{version} in the Source line instead of explicitly writing it.
- Use %%license for LICENSE and change the license in the spec file to
  GPL-3.0-only
* Fri Jul  6 2018 t.gruner@katodev.de
- update to 1.2.0
  * #61: Support for Borg --list option via borgmatic command-line to list all archives.
  * #61: Support for Borg --info option via borgmatic command-line to display summary information.
  * #62: Update README to mention other ways of installing borgmatic.
  * Support for Borg --prefix option for consistency checks via "prefix" option in borgmatic's
  consistency configuration.
  * Add introductory screencast link to documentation.
  * #59: Ignore "check_last" and consistency "prefix" when "archives" not in consistency checks.
  * #60: Add "Persistent" flag to systemd timer example.
  * #63: Support for Borg --nobsdflags option to skip recording bsdflags (e.g. NODUMP, IMMUTABLE) in
  archive.
  * #69: Support for Borg prune --umask option using value of existing "umask" option in borgmatic's
  storage configuration.
  * Update tox.ini to only assume Python 3.x instead of Python 3.4 specifically.
  * Add ~/.config/borgmatic/config.yaml to default configuration path probing.
  * Document how to develop on and contribute to borgmatic.
* Tue Mar 27 2018 t.gruner@katodev.de
- Use README.md form source
- Add borgmatic.d folder in /etc for config files
- Update to 1.1.15
  * Support for Borg BORG_PASSCOMMAND environment variable to read a password from an external file.
  * Fix for Borg create error when using borgmatic's --dry-run and --verbosity options together.
  Work-around for behavior introduced in Borg 1.1.3: https://github.com/borgbackup/borg/issues/3298
  * #55: Fix for missing tags/releases on Gitea and GitHub project hosting.
  * #56: Support for Borg --lock-wait option for the maximum wait for a repository/cache lock.
  * #58: Support for using tilde in exclude_patterns to reference home directory.
* Tue Jan 30 2018 alarrosa@suse.com
- Removed _service file. Borgmatic uses to have frequent releases these days.
- Update to 1.1.14
  * Fix for typo in --patterns-from option.
  * Support for Borg --dry-run option via borgmatic command-line.
- Update to 1.1.13
  * Fix for incorrect consistency check flags passed to Borg when all three checks ("repository",
    "archives", and "extract") are specified in borgmatic configuration.
  * Add "local_path" to configuration for specifying an alternative Borg executable path.
  * Support for Borg experimental --patterns-from and --patterns options for specifying mixed
    includes/excludes.
  * Moved issue tracker from Taiga to integrated Gitea tracker at
    https://projects.torsion.org/witten/borgmatic/issues
- Update to 1.1.12
  * Declare dependency on pykwalify 1.6 or above, as older versions yield "Unknown key: version"
    rule errors.
  * Support for Borg --keep-minutely prune option.
- Update to 1.1.11
  * Add "ssh_command" to configuration for specifying a custom SSH command or options.
  * Fix for incorrect /etc/borgmatic.d/ configuration path probing on macOS. This problem manifested
    as an error on startup: "[Errno 2] No such file or directory: '/etc/borgmatic.d'".
- Update to 1.1.10
  * Pass several Unix signals through to child processes like Borg. This means that Borg now properly
    shuts down if borgmatic is terminated (e.g. due to a system suspend).
  * Support for using tilde in repository paths to reference home directory.
  * Support for Borg --files-cache option for setting the files cache operation mode.
  * Support for Borg --remote-ratelimit option for limiting upload rate.
  * Log invoked Borg commands when at highest verbosity level.
* Sun Oct 29 2017 alarrosa@suse.com
- Upstream moved from mercurial to git, so updated _service accordingly,
  updated source code to 6e9e7c4 and set all services mode to disabled.
- Fixed a too restrictive python3-ruamel.yaml version requirement
  in the source code
- Add a rcborgmatic symlink as required by the suse-missing-rclink rpmlint check
* Wed Sep 20 2017 alarrosa@suse.com
- Update to 1.1.9dev0-201
  * #29: Support for using tilde in source directory path to reference home directory.
- python3-ruamel.yaml and python3-pykwalify are now required
- Update to 1.1.8
  * #39: Fix to make /etc/borgmatic/config.yaml optional rather than required when using the default
    config paths.
- Update to 1.1.7
  * #28: Add "archive_name_format" to configuration for customizing archive names.
  * Fix for traceback when "exclude_from" value is empty in configuration file.
  * When pruning, make highest verbosity level list archives kept and pruned.
  * Clarification of Python 3 pip usage in documentation.
- Update to 1.1.6
  * #12, #35: Support for Borg --exclude-from, --exclude-caches, and --exclude-if-present options.
- Update to 1.1.5
  * #34: New "extract" consistency check that performs a dry-run extraction of the most recent
    archive.
- Update to 1.1.4
  * #17: Added command-line flags for performing a borgmatic run with only pruning, creating, or
    checking enabled. This supports use cases like running consistency checks from a different cron
    job with a different frequency, or running pruning with a different verbosity level.
- Update to 1.1.3
  * #14: Support for running multiple config files in /etc/borgmatic.d/ from a single borgmatic run.
  * Fix for generate-borgmatic-config writing config with invalid one_file_system value.
- Update to 1.1.2
  * #32: Fix for passing check_last as integer to subprocess when calling Borg.
- Update to 1.1.1
  * Part of #32: Fix for upgrade-borgmatic-config converting check_last option as a string instead of
    an integer.
  * Fix for upgrade-borgmatic-config erroring when consistency checks option is not present.
- Update to 1.1.0
  * Switched config file format to YAML. Run upgrade-borgmatic-config to upgrade.
  * Added generate-borgmatic-config command for initial config creation.
  * Dropped Python 2 support. Now Python 3 only.
  * #18: Fix for README mention of sample files not included in package.
  * #22: Sample files for triggering borgmatic from a systemd timer.
  * Support for backing up to multiple repositories.
  * To free up space, now pruning backups prior to creating a new backup.
  * Enabled test coverage output during tox runs.
  * Added logo.
* Wed Mar  8 2017 sfalken@opensuse.org
- Edited %%files to clear unpackaged files builderror in
  openSUSE:Factory
* Sun Oct 30 2016 jengelh@inai.de
- Trim and wrap description
* Thu Oct 13 2016 alarrosa@suse.com
- version 1.0.3-dev: initial build
